@@ -205,8 +205,8 @@ class Api:
                     d_type = item[0:start]
 
                     # Ignore 
-                    # if d_type in "blank":
-                    #     break
+                    if d_type in "blank":
+                        break
                 else:
                     json_dev = item.split('" ')
                     obj = {}
